@@ -4,6 +4,8 @@
 # Copyright: (2013-2017) Michael Till Beck <Debianguru@gmx.de>
 # License: GPL-2.0+
 
+#test
+
 import io
 from lxml import etree
 import hashlib
@@ -78,7 +80,7 @@ def sendmail(receiver, subject, content, sendAsHtml, link, encoding=None):
     else:
         if link is not None:
             content = link + '\n\n' + content
-        mail = MIMEText(content, 'text', encoding)
+        mail = MIMEText(content, 'plain', encoding)
 
     mail['From'] = config.sender
     mail['To'] = receiver
@@ -93,7 +95,7 @@ def sendmail(receiver, subject, content, sendAsHtml, link, encoding=None):
         if config.smtpusername is not None:
             mailsession.login(config.smtpusername, config.smtppwd)
 
-    mailsession.sendmail(config.sender, receiver.split(','), mail.as_string())
+    mailsession.send_message(mail)
 
 
 # returns a list of all content that is stored locally for a specific site
@@ -170,7 +172,7 @@ def pollWebsites():
                     sessionHashes.append(contenthash)
                     changedContents.append(content)
 
-                    subject = '[' + site['name'] + '] ' + content.title
+                    subject = '[' + site['name'] + '] ' + ("Update available" if content.title is None else content.title)
                     print('    ' + subject)
                     if config.enableMailNotifications and len(fileHashes) > 0:
                         sendAsHtml = (content.contenttype == 'html')
